import redis

class redisUtil:
    # 创建连接池并连接到redis，并设置最大连接数量;
    # conn_pool = redis.ConnectionPool(host='192.168.31.11',
    #                                  port=6379,
    #                                  max_connections=10,
    #                                  password='120721')
    conn_pool = redis.ConnectionPool(host='home.hddly.cn',
                                     port=56379,
                                     max_connections=10,
                                     password='120721')
    # 第一个客户端访问
    # re_pool = redis.Redis(connection_pool=conn_pool)

    #在集合中添加值
    def sadd(self,setname,setvalues):
        re_pool = redis.Redis(connection_pool=self.conn_pool)
        re_pool.sadd(setname,setvalues)

    #将一个或多个值 value 插入到列表 key 的表尾(最右边)
    def rpush(self,setname,setvalues):
        re_pool = redis.Redis(connection_pool=self.conn_pool)
        re_pool.rpush(setname, setvalues)

    #移除并返回列表 key 的头元素
    def lpop(self,setname):
        re_pool = redis.Redis(connection_pool=self.conn_pool)
        return re_pool.lpop(setname)
    #在集合中添加值
    def spop(self,setname):
        re_pool = redis.Redis(connection_pool=self.conn_pool)
        return re_pool.spop(setname)

    #在集合中判断值存在
    def sismember(self,setname,setvalue):
        re_pool = redis.Redis(connection_pool=self.conn_pool)
        return re_pool.sismember(setname,setvalue)

    #在集合中删除某个元素
    def sremove(self,setname,setvalue):
        re_pool = redis.Redis(connection_pool=self.conn_pool)
        return re_pool.srem(setname,setvalue)

    #将集合中的所有元素删除
    def sremoveall(self,setname):
        re_pool = redis.Redis(connection_pool=self.conn_pool)
        value=re_pool.spop(setname)
        i=0
        while (value):
            value = re_pool.spop(setname)
            i=i+1
        return i

    #获取集合元素个数
    def scard(self,setname):
        re_pool = redis.Redis(connection_pool=self.conn_pool)
        return re_pool.scard(setname)

    #设置字典中的键值
    def hset(self,setdname, setkey, setvalue):
        re_pool = redis.Redis(connection_pool=self.conn_pool)
        re_pool.hset(setdname, setkey, setvalue)

    # 获取字典中的键值
    def hget(self,setdname, setkey):
        re_pool = redis.Redis(connection_pool=self.conn_pool)
        re_pool.hget(setdname, setkey)

    # 获取字典中的键值
    def hgetall(self,setdname):
        re_pool = redis.Redis(connection_pool=self.conn_pool)
        # re_pool.hlen(setdname)
        return re_pool.hgetall(setdname)


import os

import paramiko
from bgutils.mysqlUtil import mysqlUtil
from moviepy.editor import VideoFileClip


class ftpUtil:
    # 登陆参数设置
    __hostname = "home.hddly.cn"
    __host_port = 8021
    __username_media = "ftpuser"
    __password_media = "ywq20120721"
    __username_stud ="student"
    __password_stud ="student"
    __remotedir_media = "media/"
    __remotedir_stud = "student/"
    __url_head="https://home.hddly.cn:8443/stud/"
    __mutil= mysqlUtil()

    def chk_file_exist_surl(self,surl,fdesc):
        return self.__mutil.chk_file_exist_surl(surl,fdesc)

    def putfile_project(self, local_path, prj_id, stud_id, no_file,fdesc,surl):
        # # 要传输文件的路径
        # filepath = "./myname.jpg"
        # # 上传后的传输文件的文件名
        # remote_file = 项目ID(6位)+学生ID（11位）+文件ID(2位)+文件类型
        # 如P22001_20190010011_01.jpg
        try:
            ftype = os.path.splitext(local_path)[-1]
            if ftype.upper()=='.MP4' or ftype.upper()=='.WMV':
                clip=VideoFileClip(local_path)
                duration=clip.duration
            else:
                duration=0
            fsize=os.path.getsize(local_path)
            # 根据文件大小fsize和时间duration，在数据库中判断是否已采集(>0)，是的话就返回，否则继续
            iexist=self.__mutil.chk_file_exist(fdesc,fsize,duration)
            if iexist>0:
                print("repeat：%s,%d,%f" % (fdesc,fsize,duration))
                return
            transport = paramiko.Transport((self.__hostname, self.__host_port))
            transport.connect(username=self.__username_stud, password=self.__password_stud)
            sftp = paramiko.SFTPClient.from_transport(transport)
            pid="p" + prj_id.zfill(6)
            remotepath = "%s%s"%(self.__remotedir_stud , pid)
            try:
                sftp.chdir(remotepath)
            except:
                sftp.mkdir(remotepath)
                sftp.chdir(remotepath)
            stud = stud_id.zfill(11)
            no = no_file.zfill(8)
            remote_file = "%s%s%s%s"%(pid,stud,no,ftype)
            sftp.put(local_path, remote_file)
            print('success upload......')
            sftp.close()
            transport.close()
        except Exception as ex:
            print("connect error:%s" % ex)

        try:
            # 记录文件列表
            # item = entSftpFile()
            # item['filename'] = local_path
            # item['url'] = self.__url_head+remote_file
            # item['stud'] = stud
            remotefullpath = "%s%s/%s" % (self.__url_head,
                                           pid,
                                           remote_file)
            self.__mutil.sftp_file_ins(local_path,
                                       remotefullpath,
                                       stud,
                                       fdesc,
                                       fsize,
                                       duration,
                                       ftype,
                                       pid,
                                       surl)
        except Exception as ex:
            print("sftp_file_ins error:%s" % ex)

    def putfile_stud(self,local_path,prj_id,stud_id,no_file):
        self.putfile_project(local_path,prj_id,stud_id,no_file,'','');


    def putfile_media(self,local_path,remote_file):
        t = paramiko.Transport((self.__hostname, self.__host_port))
        t.connect(username=self.__username_media, password=self.__password_media)
        sftp = paramiko.SFTPClient.from_transport(t)
        remote_path = self.__remotedir_media + remote_file  # 远程路径
        put_info = sftp.put(local_path, remote_path, confirm=True)
        print(put_info)
        print(f"finished put file:{local_path}.")
        t.close

    def getfile_media(self,remote_file,local_path):
        t = paramiko.Transport((self.__username_media, self.__host_port))
        t.connect(username=self.__username_media, password=self.__password_media)
        sftp = paramiko.SFTPClient.from_transport(t)
        remote_path = self.__remotedir_media + remote_file  # 远程路径
        sftp.get(remotepath=remote_path, localpath=local_path)
        print(f"finished get file:{local_path}.")
        t.close